@@ -111,7 +111,7 @@ input: |+
 		})
 
 		It("should show a binary data difference in hex dump style", func() {
-			compareAgainstExpected("../../assets/binary/from.yml",
+			compareAgainstExpectedHuman("../../assets/binary/from.yml",
 				"../../assets/binary/to.yml",
 				"../../assets/binary/dyff.expected",
 				false,
@@ -119,13 +119,13 @@ input: |+
 		})
 
 		It("should show the testbed results as expected", func() {
-			compareAgainstExpected("../../assets/testbed/from.yml",
+			compareAgainstExpectedHuman("../../assets/testbed/from.yml",
 				"../../assets/testbed/to.yml",
 				"../../assets/testbed/expected-dyff-spruce.human",
 				false,
 			)
 
-			compareAgainstExpected("../../assets/testbed/from.yml",
+			compareAgainstExpectedHuman("../../assets/testbed/from.yml",
 				"../../assets/testbed/to.yml",
 				"../../assets/testbed/expected-dyff-gopatch.human",
 				true,
@@ -143,7 +143,7 @@ input: |+
 		})
 
 		It("should show nicely colored difference output", func() {
-			compareAgainstExpected(
+			compareAgainstExpectedHuman(
 				"../../assets/colors/from.yml",
 				"../../assets/colors/to.yml",
 				"../../assets/colors/dyff.expected",
@@ -192,10 +192,19 @@ variables.ROUTER_TLS_PEM.options
 		})
 
 		It("should use human friendly compact diff of multiline text differences", func() {
-			compareAgainstExpected(
-				assets("kubernetes-configmaps/from.yml"),
-				assets("kubernetes-configmaps/to.yml"),
-				assets("kubernetes-configmaps/expected-dyff-spruce.human"),
+			compareAgainstExpectedHuman(
+				assets("kubernetes/configmaps/from.yml"),
+				assets("kubernetes/configmaps/to.yml"),
+				assets("kubernetes/configmaps/expected-dyff-spruce.human"),
+				false,
+			)
+		})
+
+		It("should use human friendly compact diff of multiline text differences for complex files", func() {
+			compareAgainstExpectedHuman(
+				assets("multiline/from.yml"),
+				assets("multiline/to.yml"),
+				assets("multiline/expected-dyff-spruce.human"),
 				false,
 			)
 		})
@@ -211,7 +220,7 @@ variables.ROUTER_TLS_PEM.options
 		})
 
 		It("should use correct indentions for all kind of changes", func() {
-			compareAgainstExpected("../../assets/issues/issue-89/from.yml",
+			compareAgainstExpectedHuman("../../assets/issues/issue-89/from.yml",
 				"../../assets/issues/issue-89/to.yml",
 				"../../assets/issues/issue-89/expected-dyff-spruce.human",
 				false,
@@ -229,7 +238,7 @@ variables.ROUTER_TLS_PEM.options
 		})
 
 		It("should not parse markdown in multiline text diff output", func() {
-			compareAgainstExpected(
+			compareAgainstExpectedHuman(
 				assets("issues", "issue-225", "from.yml"),
 				assets("issues", "issue-225", "to.yml"),
 				assets("issues", "issue-225", "expected-dyff-spruce.human"),
